#
# spec file for package dd-opentracing-cpp
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 0
%define libname libdd_opentracing%{soversion}

Name:           dd-opentracing-cpp
Version:        1.1.2
Release:        lp152.1.4
Summary:        Datadog Opentracing C++ client
License:        Apache-2.0
Group:          Development/Languages/C and C++
Url:            https://github.com/DataDog/dd-opentracing-cpp
Source:         %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libcurl-devel
BuildRequires:  msgpack-devel
BuildRequires:  nlohmann_json-devel
BuildRequires:  opentracing-cpp-devel
BuildRequires:  zlib-devel

%description
C++ client for Datalog Opentracing.

%package -n %{libname}
Summary:        Shared library for Datalog Opentracing C++ client
Group:          System/Libraries

%description -n %{libname}
Shared library for dd-opentracing-cpp - C++ client for Datalog Opentracing.

%package devel
Summary:        Development files for Datalog Opentracing C++ client
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}

%description devel
Development files for dd-opentracing-cpp - C++ client for Datalog Opentracing.

%prep
%setup -q
# Use version packaged in distribution
rm -r 3rd_party/include/nlohmann

%build
%cmake
%make_jobs

%install
%cmake_install

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%doc README.md
%{_libdir}/libdd_opentracing.so.0

%files devel
%{_includedir}/datadog
%{_includedir}/datadog/opentracing.h
%{_libdir}/libdd_opentracing.so

%changelog
* Tue Dec 17 2019 mrostecki@opensuse.org
- Update to version 1.1.2:
  * Fix nginx example / sandbox (#114)
  * Generate int64 values instead of uint64 (#116)
  * version bump for 1.1.1 and version check scripts enforced by CI (#113)
  * Build / install updates  (#112)
  * Changed how tests are built for faster compilation (#109)
  * Replace ':' in span tag keys with '.' (#107)
* Tue Aug  6 2019 antoine.belvire@opensuse.org
- Update to version 1.0.1:
  * Fix compile errors when built by some tasks on Envoy CI
    (gh#DataDog/dd-opentracing-cpp#106).
- Changes from version 1.0.0:
  * Features:
    + Add code changes needed to support Datadog Synthetics.
    + Add code for trace analytics.
    + Add code for DD_TRACE_REPORT_HOSTNAME, used when the agent
    is on a different host.
    + Add code for DD_ENV to set the env attribute of traces.
    + Add support for trace analytics controlled by environment
    variables.
  * Fixes:
    + Revert nginx implementation to use nginx-opentracing.
    + Add tags for manual_keep and manual_drop.
    + Remove a redundant move, fix build with GCC 9.
    + Workaround for integration test failure.
    + Missing header in BUILD.bazel.
    + Outdated examples removed.
    + README improvements.
- Changes from version 0.4.3:
  * Supports nginx-opentracing v0.8.0, updates other dependencies.
  * Updates documentation.
- Changes from version 0.4.2:
  * Minor improvement to operation_name_override behaviour.
- Changes from version 0.4.1:
  * Inject/extract methods can be configured with env vars.
- Build against nlohmann_json-devel provided by distribution
  instead of the version embedded in tarball.
* Fri Jan 11 2019 Michał Rostecki <mrostecki@suse.de>
- Update to version 0.4.0:
  * Add test for header whitelist
  * Fix propagation header whitelist
  * Add missing docker-compose.yml file in C++ example
  * Allow to use custom libdir and includedir in cmake
  * Add SOVERSION in cmake
* Tue Dec 11 2018 Michał Rostecki <mrostecki@suse.de>
- Call ldconfig on post-(un)installation.
* Tue Dec 11 2018 Michał Rostecki <mrostecki@suse.de>
- Initial release - 0.3.8
